# Changelog
## 0.1.6- Standardize README structure and fix compliance issues
## 0.1.5- Add pytest and mypy tool configuration to pyproject.toml

## 0.1.4

- Add basic import test

## 0.1.3

- Add Development section to README

## 0.1.0 (2026-03-10)

- Initial release
- ASGI middleware for FastAPI/Starlette
- WSGI middleware for Flask/Django
- Slow request threshold warnings
- Server-Timing response header
